@@ -1,14 +1,56 @@
 /* cfgfile.c
- * Part of ziproxy package.
- * 
- * Copyright (c)2003-2004 Juraj Variny<variny@naex.sk>
+ * Configuration file parsing functions.
+ *
+ * Ziproxy - the HTTP acceleration proxy
+ * This code is under the following conditions:
+ *
+ * ---------------------------------------------------------------------
  * Copyright (c)2005-2010 Daniel Mealha Cabrita
  *
- * Released subject to GNU General Public License v2 or later version.
- * 
- * Configuration file parsing functions.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111 USA
+ * ---------------------------------------------------------------------
+ *
+ * This code also contains portions under the following conditions:
+ *
+ * ---------------------------------------------------------------------
+ * Copyright (c) Juraj Variny, 2004
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ * THIS SOFTWARE IS PROVIDED BY JURAJ VARINY
+ * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
+ * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+ * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR CONTRIBUTORS
+ * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ * POSSIBILITY OF SUCH DAMAGE.
+ * ---------------------------------------------------------------------
  */
 
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -23,6 +65,8 @@
 #include <resolv.h>
 #include <pwd.h>
 #include <grp.h>
+#include <sys/stat.h>
+#include <unistd.h>
 
 #include "qparser.h"
 #include "image.h"
@@ -54,7 +98,6 @@ char *AccessLogFileName; // deprecated
 char *DebugLog;
 char *AccessLog;
 char *ErrorLog;
-char *PasswdFile;
 char *RedefineUserAgent;
 char *URLNoProcessing;
 char *URLReplaceData;
@@ -83,6 +126,12 @@ char *cli_RunAsUser;
 char *RunAsGroup;
 char *cli_RunAsGroup;
 
+int AuthMode;
+char *AuthPasswdFile;
+#ifdef SASL
+char *AuthSASLConfPath;
+#endif
+
 #ifdef JP2K
 t_qp_bool ProcessJP2, ForceOutputNoJP2, ProcessToJP2, AnnounceJP2Capability, JP2OutRequiresExpCap;
 int JP2Colorspace_cfg;
@@ -107,6 +156,7 @@ const t_ut_urltable *load_URLtable (const char *urltable_filename);
 const t_ct_cttable *LoadParmMatrixCT (t_qp_configfile *conf_handler, const char *conf_key, const char **dvalues, int dvalues_len, const int min_entries, const int max_entries, const int subtype_add_x_prefix);
 int check_int_ranges (const char *conf_key, const int inval, const int vlow, const int vhigh);
 int check_int_minimum (const char *conf_key, const int inval, const int vlow);
+int check_directory (const char *conf_key, const char *dirname);
 
 const t_ut_urltable *tos_markasdiff_url;
 const t_ct_cttable *tos_maskasdiff_ct;
@@ -116,7 +166,6 @@ const t_ut_urltable *urltable_replacedata;
 const t_ut_urltable *urltable_replacedatact;
 const t_ct_cttable *urltable_replacedatactlist;
 const t_ut_urltable *urltable_deny;
-const t_st_strtable *passwd_table;
 
 const t_ct_cttable *lossless_compress_ct;
 
@@ -220,7 +269,6 @@ int ReadCfgFile(char * cfg_file)
 	DebugLog = NULL;
 	AccessLog = NULL;
 	ErrorLog = NULL;
-	PasswdFile = NULL;
 	AllowMethodCONNECT = QP_TRUE;
 	OverrideAcceptEncoding = QP_TRUE;
 	RedefineUserAgent = NULL;
@@ -240,7 +288,6 @@ int ReadCfgFile(char * cfg_file)
 	urltable_replacedata = NULL;
 	urltable_replacedatact = NULL;
 	urltable_replacedatactlist = NULL;
-	passwd_table = NULL;
 	InterceptCrashes = QP_FALSE;
 	TOSMarking = QP_FALSE;
 	TOSFlagsDefault = -1;
@@ -254,6 +301,11 @@ int ReadCfgFile(char * cfg_file)
 	PIDFile = cli_PIDFile;		/* defaults to CLI parameter, if specified */
 	RunAsUser = cli_RunAsUser;	/* defaults to CLI parameter, if specified */
 	RunAsGroup = cli_RunAsGroup;	/* defaults to CLI parameter, if specified */
+	AuthMode = AUTH_NONE;
+	AuthPasswdFile = NULL;
+#ifdef SASL
+	AuthSASLConfPath = NULL;
+#endif
 #ifdef JP2K
 	ProcessJP2 = QP_FALSE;
 	ForceOutputNoJP2 = QP_FALSE;
@@ -308,7 +360,6 @@ int ReadCfgFile(char * cfg_file)
 	qp_getconf_str (conf_handler, "CustomError503", &CustomError503, QP_FLAG_NONE);
 	qp_getconf_str (conf_handler, "Address", &Address, QP_FLAG_NONE);
 	qp_getconf_str (conf_handler, "AccessLogFileName", &AccessLogFileName, QP_FLAG_NONE);	// deprecated
-	qp_getconf_str (conf_handler, "PasswdFile", &PasswdFile, QP_FLAG_NONE);
 	qp_getconf_bool (conf_handler, "ProcessHTML", &ProcessHTML, QP_FLAG_NONE);
 	qp_getconf_bool (conf_handler, "ProcessCSS", &ProcessCSS, QP_FLAG_NONE);
 	qp_getconf_bool (conf_handler, "ProcessJS", &ProcessJS, QP_FLAG_NONE);
@@ -325,7 +376,6 @@ int ReadCfgFile(char * cfg_file)
 	qp_getconf_int (conf_handler, "MaxUncompressedImageRatio", &MaxUncompressedImageRatio, QP_FLAG_NONE);
 	qp_getconf_str (conf_handler, "RedefineUserAgent", &RedefineUserAgent, QP_FLAG_NONE);
 	qp_getconf_bool (conf_handler, "DecompressIncomingGzipData", &DecompressIncomingGzipData, QP_FLAG_NONE);
-	qp_getconf_array_str (conf_handler, "Nameservers", 0, NULL, QP_FLAG_NONE);
 	qp_getconf_bool (conf_handler, "WA_MSIE_FriendlyErrMsgs", &WA_MSIE_FriendlyErrMsgs, QP_FLAG_NONE);
 	qp_getconf_bool (conf_handler, "InterceptCrashes", &InterceptCrashes, QP_FLAG_NONE);
 	qp_getconf_int (conf_handler, "MinUncompressedGzipStreamEval", &MinUncompressedGzipStreamEval, QP_FLAG_NONE);
@@ -351,6 +401,13 @@ int ReadCfgFile(char * cfg_file)
 	qp_getconf_str (conf_handler, "PIDFile", &PIDFile, QP_FLAG_NONE);
 	qp_getconf_str (conf_handler, "RunAsUser", &RunAsUser, QP_FLAG_NONE);
 	qp_getconf_str (conf_handler, "RunAsGroup", &RunAsGroup, QP_FLAG_NONE);
+	qp_getconf_int (conf_handler, "AuthMode", &AuthMode, QP_FLAG_NONE);
+	qp_getconf_str (conf_handler, "AuthPasswdFile", &AuthPasswdFile, QP_FLAG_NONE);
+#ifdef SASL
+	qp_getconf_str (conf_handler, "AuthSASLConfPath", &AuthSASLConfPath, QP_FLAG_NONE);
+#else
+	qp_set_parameter_status (conf_handler, QP_PARM_STATUS_NOT_SUPPORTED, "AuthSASLConfPath"); /* no SASL support */
+#endif
 #ifdef JP2K
 	qp_getconf_bool (conf_handler, "ProcessJP2", &ProcessJP2, QP_FLAG_NONE);
 	qp_getconf_bool (conf_handler, "ForceOutputNoJP2", &ForceOutputNoJP2, QP_FLAG_NONE);
@@ -382,6 +439,11 @@ int ReadCfgFile(char * cfg_file)
 	qp_set_parameter_status (conf_handler, QP_PARM_STATUS_NOT_SUPPORTED, "JP2CSamplingRGBA");
 	qp_set_parameter_status (conf_handler, QP_PARM_STATUS_NOT_SUPPORTED, "JP2CSamplingYUVA");
 #endif
+#ifdef EN_NAMESERVERS
+	qp_getconf_array_str (conf_handler, "Nameservers", 0, NULL, QP_FLAG_NONE);
+#else
+	qp_set_parameter_status (conf_handler, QP_PARM_STATUS_NOT_SUPPORTED, "Nameservers");
+#endif
 
 	/* list of OBSOLETE parameters, but we still recognize those parameters
 	   in order to provide a more informative error message */
@@ -394,6 +456,7 @@ int ReadCfgFile(char * cfg_file)
 	qp_set_parameter_status (conf_handler, QP_PARM_STATUS_OBSOLETE, "MSIETest");
 	qp_set_parameter_status (conf_handler, QP_PARM_STATUS_OBSOLETE, "AccessLogUserPOV");
 	qp_set_parameter_status (conf_handler, QP_PARM_STATUS_OBSOLETE, "NetdTimeout");
+	qp_set_parameter_status (conf_handler, QP_PARM_STATUS_OBSOLETE, "PasswdFile");
 
 	/* init error_log as soon as possible! */
 	if (error_log_init (ErrorLog) != 0) {
@@ -498,12 +561,43 @@ int ReadCfgFile(char * cfg_file)
 			return (1);
 	}
 
-	if (PasswdFile != NULL) {
+	/* authentication settings */
+	if (check_int_ranges ("AuthMode", AuthMode, AUTH_MIN, AUTH_MAX))
+		return (1);
+	if (AuthMode == AUTH_PASSWD_FILE) {
+		if (AuthPasswdFile == NULL) {
+			error_log_puts (LOGMT_FATALERROR, LOGSS_CONFIG,
+				"Specified AuthMode requires defined AuthPasswdFile.");
+			return (1);
+		}
+
 		// FIXME: this table is not manually deallocated later, thus it is not zero'ed
 		// when ziproxy daemon/process finishes. That's a security vulnerability.
-		if ((passwd_table = auth_create_populate_from_file (PasswdFile)) == NULL)
+		if (auth_passwdfile_init (AuthPasswdFile)) {
+			error_log_printf (LOGMT_FATALERROR, LOGSS_CONFIG,
+				"Error while loading AuthPasswdFile from: %s\n", AuthPasswdFile);
 			return (1);
+		}
+	} else if (AuthMode == AUTH_SASL) {
+#ifdef SASL
+		if (AuthSASLConfPath != NULL) {
+			if (check_directory ("AuthSASLConfPath", AuthSASLConfPath))
+				return (1);
+		}
+
+		if (auth_sasl_init (AuthSASLConfPath)) {
+			error_log_puts (LOGMT_FATALERROR, LOGSS_CONFIG,
+				"Error while initializing SASL.");
+			return (1);
+		}
+#else
+		error_log_puts (LOGMT_FATALERROR, LOGSS_CONFIG,
+			"Specified AuthMode requires SASL, which is not supported.");
+		return (1);
+#endif
+
 	}
+	auth_set_mode (AuthMode);
 
 	if (TOSMarkAsDiffURL != NULL) {
 		if((tos_markasdiff_url = load_URLtable (TOSMarkAsDiffURL)) == NULL)
@@ -655,18 +749,19 @@ int ReadCfgFile(char * cfg_file)
 
 	if (LoadParmMatrix(ImageQuality, conf_handler, "ImageQuality", DefaultImageQuality, 4, 4, 0, 100) < 0)
 			return (1);
-		
+
+#ifdef EN_NAMESERVERS		
 	n = qp_get_array_size (conf_handler, "Nameservers");
 	if (n) {
-		struct sockaddr_in nsaddr;
+		struct sockaddr_in nsaddr_new;
 
 		if (n > MAXNS) {
 			error_log_printf (LOGMT_ERROR, LOGSS_CONFIG, "You can not specify more than %d Nameservers.\n", MAXNS);
 			error_log_printf (LOGMT_INFO, LOGSS_CONFIG, "Using nameserver 1 to %d and ignoring the rest.\n", MAXNS);
 		}
 
-		nsaddr.sin_family = AF_INET;
-		nsaddr.sin_port = htons(53);
+		nsaddr_new.sin_family = AF_INET;
+		nsaddr_new.sin_port = htons(53);
 
 		res_init();
 		_res.nscount = 0;
@@ -675,10 +770,11 @@ int ReadCfgFile(char * cfg_file)
 			char *nserver_str;
 			
 			qp_getconf_array_str (conf_handler, "Nameservers", i, &nserver_str, QP_FLAG_NONE);
-			inet_aton(nserver_str, &nsaddr.sin_addr);
-			_res.nsaddr_list[_res.nscount++] = nsaddr;
+			inet_aton(nserver_str, &nsaddr_new.sin_addr);
+			_res.nsaddr_list[_res.nscount++] = nsaddr_new;
 		}
 	}
+#endif
 
 	if (check_int_ranges ("MaxUncompressedImageRatio", MaxUncompressedImageRatio, 0, 100000))
 		return (1);
@@ -1039,6 +1135,22 @@ int check_int_minimum (const char *conf_key, const int inval, const int vlow)
 	return (0);
 }
 
+/* returns: ==0 if dirname is a directory,
+   or !=0 (error) if does not exist or not a directory */
+int check_directory (const char *conf_key, const char *dirname)
+{
+	struct stat f_stat;
+
+	if (stat (dirname, &f_stat) == 0) {
+		if (S_ISDIR (f_stat.st_mode))
+			return (0);
+	}
+
+	error_log_printf (LOGMT_FATALERROR, LOGSS_CONFIG,
+		"%s specifies an invalid directory path: %s\n", conf_key, dirname);
+	return (1);
+}
+
 /* try to switch process to specified user and group.
    if group is unspecified (NULL), use the user's group.
    if both user_name and group_name == NULL, then do nothing and return 0.
