@@ -1,12 +1,53 @@
 /* cfgfile.h
- * Part of ziproxy package.
- * 
- * Copyright (c)2003-2004 Juraj Variny<variny@naex.sk>
+ * Configuration file parsing functions.
+ *
+ * Ziproxy - the HTTP acceleration proxy
+ * This code is under the following conditions:
+ *
+ * ---------------------------------------------------------------------
  * Copyright (c)2005-2010 Daniel Mealha Cabrita
  *
- * Released subject to GNU General Public License v2 or later version.
- * 
- * Configuration file parsing functions.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111 USA
+ * ---------------------------------------------------------------------
+ *
+ * This code also contains portions under the following conditions:
+ *
+ * ---------------------------------------------------------------------
+ * Copyright (c) Juraj Variny, 2004
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ * THIS SOFTWARE IS PROVIDED BY JURAJ VARINY
+ * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
+ * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+ * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR CONTRIBUTORS
+ * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ * POSSIBILITY OF SUCH DAMAGE.
+ * ---------------------------------------------------------------------
  */
 
 //To stop multiple inclusions.
@@ -48,7 +89,6 @@ extern char *Address;
 extern char *DebugLog;
 extern char *AccessLog;
 extern char *ErrorLog;
-extern char *PasswdFile;
 extern char *RedefineUserAgent;
 extern char *URLNoProcessing;
 extern char *URLReplaceData;
@@ -82,10 +122,15 @@ extern const t_ut_urltable *urltable_replacedata;
 extern const t_ut_urltable *urltable_replacedatact;
 extern const t_ct_cttable *urltable_replacedatactlist;
 extern const t_ut_urltable *urltable_deny;
-extern const t_st_strtable *passwd_table;
 
 extern const t_ct_cttable *lossless_compress_ct;
 
+extern int AuthMode;
+extern char *AuthPasswdFile;
+#ifdef SASL
+extern char *AuthSASLConfPath;
+#endif
+
 #ifdef JP2K
 extern int JP2ImageQuality[4];
 extern t_qp_bool ProcessJP2, ForceOutputNoJP2, ProcessToJP2, AnnounceJP2Capability, JP2OutRequiresExpCap;
