@@ -1,12 +1,53 @@
 /* http.c
- * Part of ziproxy package.
- * 
- * Copyright (c)2003-2004 Juraj Variny<variny@naex.sk>
+ * HTTP communication functions.
+ *
+ * Ziproxy - the HTTP acceleration proxy
+ * This code is under the following conditions:
+ *
+ * ---------------------------------------------------------------------
  * Copyright (c)2005-2010 Daniel Mealha Cabrita
  *
- * Released subject to GNU General Public License v2 or later version.
- * 
- * HTTP communication functions.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111 USA
+ * ---------------------------------------------------------------------
+ *
+ * This code also contains portions under the following conditions:
+ *
+ * ---------------------------------------------------------------------
+ * Copyright (c) Juraj Variny, 2004
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ * THIS SOFTWARE IS PROVIDED BY JURAJ VARINY
+ * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
+ * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+ * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR CONTRIBUTORS
+ * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ * POSSIBILITY OF SUCH DAMAGE.
+ * ---------------------------------------------------------------------
  */
 
 #ifdef HAVE_CONFIG_H
@@ -892,7 +933,7 @@ http_headers * parse_initial_request(void){
 		else
 		    send_error( 400, "Bad Request", NULL, "Can't parse URL." );
 
-		if (PasswdFile != NULL) {
+		if (AuthMode != AUTH_NONE) {
 			// Look for auth header
 			while (fgets (line, sizeof (line), sess_rclient) != NULL)
 			{
@@ -902,8 +943,8 @@ http_headers * parse_initial_request(void){
 				if ((strncasecmp (line, "Proxy-Authorization: Basic ", 27) == 0) && (strlen (line) > 30)) {
 					char *username;
 
-					// check if user/password match any entry in PasswdFile
-					was_auth = check_authentication (passwd_table, line + 27);
+					// check if user/password is valid
+					was_auth = auth_basic_check (line + 27);
 
 					// get username (from auth basic composite string) for access log
 					if ((username = auth_get_username (line + 27)) != NULL) {
@@ -987,13 +1028,13 @@ void get_client_headers(http_headers * hdr){
 				continue;
 
 		// does special processing only if proxy authentication is required
-		if (PasswdFile != NULL) {
+		if (AuthMode != AUTH_NONE) {
 			if (strncasecmp(line,"Proxy-Authorization:",20) == 0 && strlen(line) > 30) {
 				if ((strncasecmp (line, "Proxy-Authorization: Basic ", 27) == 0) && (strlen (line) > 30)) {
 					char *username;
 
-					// check if user/password match any entry in PasswdFile
-					was_auth = check_authentication (passwd_table, line + 27);
+					// check if user/password is valid
+					was_auth = auth_basic_check (line + 27);
 
 					// get username (from auth basic composite string) for access log
 					if ((username = auth_get_username (line + 27)) != NULL) {
@@ -1098,7 +1139,7 @@ void get_client_headers(http_headers * hdr){
 		add_header(hdr, line);
 	}
 
-	if ((PasswdFile != NULL) && !was_auth) {
+	if ((AuthMode != AUTH_NONE) && (! was_auth)) {
 		debug_log_puts ("Requesting HTTP auth from client");
 		send_error( 407, "Proxy Authentication Required", "Proxy-Authenticate: Basic realm=\"internet\"", "You have to be registered before using this proxy.");
 	}
