@@ -1,17 +1,55 @@
-//
-// netd.c : wrapper for ziproxy - user mode inetd replacement
-// This code used to generate the 'netd' executable
-// now it is the core for the 'ziproxy' executable (netd is obsolete)
-// 
-// Copyright (c)2002-2004 Juraj Variny<variny@naex.sk>
-// Copyright (c)2005-2010 Daniel Mealha Cabrita
-// 
-// Based on
-// proxy.c from microproxy package:
-// (c) May 2001, by David McNab - david@rebirthing.co.nz, http://freeweb.sf.org
-// 
-// Released subject to GNU General Public License v2 or later version.
-//
+/* netd.c
+ * Core daemon routines.
+ *
+ * Ziproxy - the HTTP acceleration proxy
+ * This code is under the following conditions:
+ *
+ * ---------------------------------------------------------------------
+ * Copyright (c)2005-2010 Daniel Mealha Cabrita
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111 USA
+ * ---------------------------------------------------------------------
+ *
+ * This code also contains portions under the following conditions:
+ *
+ * ---------------------------------------------------------------------
+ * Copyright (c) Juraj Variny, 2004
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ * THIS SOFTWARE IS PROVIDED BY JURAJ VARINY
+ * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
+ * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+ * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR CONTRIBUTORS
+ * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ * POSSIBILITY OF SUCH DAMAGE.
+ * ---------------------------------------------------------------------
+ */
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -46,12 +84,6 @@
 #include "txtfiletools.h"
 #include "session.h"
 
-#define SockAddrType					struct sockaddr_in
-
-//
-// PRIVATE DECLARATIONS
-//
-
 int	proxy_server ();
 int	proxy_handlereq (SOCKET sock_client, const char *client_addr, struct sockaddr_in *socket_host);
 void	process_request (const char *client_addr, struct sockaddr_in *socket_host, SOCKET sock_child_out);
@@ -317,20 +349,17 @@ int main(int argc, char **argv, char *env[])
 	return proxy_server(&(command_options.addr_low), &(command_options.addr_high));
 }
 
-
-//
-// main thread which listens for incoming http connections, and launches a child process
-// when a connection comes in
-//
+/* daemon core */
 int proxy_server(struct in_addr *addr_low, struct in_addr *addr_high)
 {
-	SOCKET			  sock_listen, sock_client;
-	int						one = 1,sin_size,Status;
+	SOCKET sock_listen, sock_client;
+	int sin_size, Status;
+	int so_val = 1;
 	// These are addresses in host byte order for comparison purpose.
 	uint32_t addr_low_host, addr_high_host, connection_host;
 	struct timeval tv;
 	fd_set readfds;
-	SockAddrType	sockAddr,gotConn;
+	struct sockaddr_in sockAddr, gotConn;
 	int which_BindOutgoing = 0;
 	struct sockaddr_in pre_socket_host;
 	struct sockaddr_in *socket_host = NULL;
@@ -346,11 +375,10 @@ int proxy_server(struct in_addr *addr_low, struct in_addr *addr_high)
 			sockAddr.sin_addr.s_addr = inet_addr(Address);
 	}
 	
-	// bind the socket
 	sock_listen = socket(AF_INET, SOCK_STREAM, 0);
-	//Status = setsockopt (sock_listen, IPPROTO_TCP, TCP_NODELAY, (char * ) &one, sizeof (int));
+
         /* FIXME: netd does not close the socket while exiting, this is just a workaround */
-        Status = setsockopt (sock_listen, SOL_SOCKET, SO_REUSEADDR, &one, sizeof (one));
+        Status = setsockopt (sock_listen, SOL_SOCKET, SO_REUSEADDR, &so_val, sizeof (so_val));
 	Status = bind(sock_listen, (struct sockaddr*) &sockAddr, sizeof(sockAddr));
 	if(Status < 0)
 	{
@@ -359,7 +387,6 @@ int proxy_server(struct in_addr *addr_low, struct in_addr *addr_high)
 		daemon_error_cleanup_privileged ();
 		return 20;
 	}
-	// set socket to listen
 	if (listen(sock_listen, SOMAXCONN) != 0)
 	{
 		error_log_printf (LOGMT_FATALERROR, LOGSS_DAEMON,
@@ -367,7 +394,7 @@ int proxy_server(struct in_addr *addr_low, struct in_addr *addr_high)
 		daemon_error_cleanup_privileged ();
 		return 21;
 	}
-	if (setsockopt (sock_listen, SOL_SOCKET, SO_REUSEADDR, &one, sizeof(int)) < 0)
+	if (setsockopt (sock_listen, SOL_SOCKET, SO_REUSEADDR, &so_val, sizeof (so_val)) < 0)
 		error_log_printf (LOGMT_ERROR, LOGSS_DAEMON, "Failed to set REUSEADDR flag on socket (port: %d).\n", Port);
 	
 	addr_low_host = ntohl(addr_low->s_addr);
@@ -384,7 +411,7 @@ int proxy_server(struct in_addr *addr_low, struct in_addr *addr_high)
 
 	error_log_puts (LOGMT_INFO, LOGSS_DAEMON, "Daemon started.");
 
-	// loop accepting connections
+	/* daemon main loop */
 	while (1)
 	{
 		/* create data structures for BindOutgoing rotation (if appliable) */
@@ -418,7 +445,7 @@ int proxy_server(struct in_addr *addr_low, struct in_addr *addr_high)
 			if ((sock_client = accept(sock_listen, (struct sockaddr *) &gotConn, &sin_size)) < 0) {
 				error_log_puts (LOGMT_ERROR, LOGSS_DAEMON, "accept() failed.");
 			}
-			// there's a new connection
+
 			if(addr_low->s_addr) {
 				connection_host = ntohl(gotConn.sin_addr.s_addr);
 				if ((connection_host < addr_low_host) ||
@@ -434,7 +461,8 @@ int proxy_server(struct in_addr *addr_low, struct in_addr *addr_high)
 fork_retry:
 			switch(fork())
 			{
-			case 0://child
+			case 0:
+				/* CHILD */
 				signal (SIGTERM, SIG_DFL); /* we don't want children using daemon's SIGTERM handler */
 				close(sock_listen);
 
@@ -448,6 +476,7 @@ fork_retry:
 
 				return proxy_handlereq (sock_client, inet_ntoa(gotConn.sin_addr), socket_host);
 			case -1:
+				/* ERROR */
 				error_log_puts (LOGMT_ERROR, LOGSS_DAEMON, "Fork() failed, waiting then retrying...\n");
 
 				/* collect terminated child procs */
@@ -462,7 +491,8 @@ fork_retry:
 
 				goto fork_retry;
 				break;				
-			default://parent
+			default:
+				/* PARENT */
 				close(sock_client);
 				curr_active_user_conn++;	/* one more active connection */
 			}
@@ -481,14 +511,12 @@ fork_retry:
 			curr_active_user_conn--;
 		}
 	}
-				// 'while (1)'
-	return(0);	// how on earth did we get here???
-}			// 'proxy_server()'
 
+	/* it should not reach this point */
+	return 0;
+}
 
-//
-// function which handles a single http request
-//
+/* handle HTTP session request */
 int proxy_handlereq (SOCKET sock_client, const char *client_addr, struct sockaddr_in *socket_host)
 {
 	sess_rclient = fdopen (sock_client, "r");
@@ -498,7 +526,7 @@ int proxy_handlereq (SOCKET sock_client, const char *client_addr, struct sockadd
 	close (sock_client);
 
 	return(0);
-}		// 'proxy_handlereq()'
+}
 
 void daemon_sigcatch (int signo)
 {
@@ -605,7 +633,6 @@ void process_command_line_arguments (int argc, char **argv)
 				break;
 			case 'h':
 				printf ("Ziproxy " VERSION "\n"
-						"Copyright (c)2002-2004 Juraj Variny\n"
 						"Copyright (c)2005-2010 Daniel Mealha Cabrita\n"
 						"\n"
 
